==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_RE","V");
define("_SUBJECT","Cm");
define("_PRIVATEMESSAGES","Szemlyes zeneteid");
define("_CHECKALL","Ellenrzs");
define("_FROM","Felad");
define("_DATE","Dtum");
define("_DONTHAVEMESSAGES","Nincs zeneted");
define("_NOTREAD","Olvasatlan");
define("_MSGSTATUS","zenetek llapota");
define("_PRIVATEMESSAGE","Szemlyes zenetek");
define("_INDEX","Index");
define("_SENT","Elkldve");
define("_PREVIOUSMESSAGE","Elz zenet");
define("_NEXTMESSAGE","Kvetkez zenet");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","A kldsrl");
define("_ALLREGCANPOST","Minden regisztrlt tag kldhet szemlyes zeneteket.");
define("_TO","Cmzett");
define("_MESSAGEICON","zenet ikonja");
define("_MESSAGE","zenet");
define("_HTML","HTML");
define("_PMON","On");
define("_PMOFF","Off");
define("_BBCODE","BBCode");
define("_WROTE","rta");
define("_OPTIONS","Belltsok");
define("_HTMLDISSABLE","HTML kikapcsolsa ebben az zenetben");
define("_BBCODEDISSABLE","<a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> kikapcsolsa");
define("_SMILEDISSABLE","<a href=\"bb_smilies.php\" target=\"_blank\"><i>vigyorok</i></a> kikapcsolsa");
define("_CANCELREPLY","Mgsem");
define("_CANCELSEND","Mgsem");
define("_CLEAR","Trls");
define("_SUBMIT","Klds");
define("_USERNOTINDB","Ilyen felhasznl nem ltezik az adatbzisban.");
define("_CHECKNAMEANDTRY","Ellenrizd a nevet, s prbld jra!");
define("_MSGPOSTED","zenet elkldve.");
define("_RETURNTOPMSG","Kattints ide a szemlyes zenetek frisstshez.");
define("_MSGDELETED","zeneteid trlve.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_RE","V");
define("_SUBJECT","Cm");
define("_PRIVATEMESSAGES","Szemlyes zeneteid");
define("_CHECKALL","Ellenrzs");
define("_FROM","Felad");
define("_DATE","Dtum");
define("_DONTHAVEMESSAGES","Nincs zeneted");
define("_NOTREAD","Olvasatlan");
define("_MSGSTATUS","zenetek llapota");
define("_PRIVATEMESSAGE","Szemlyes zenetek");
define("_INDEX","Index");
define("_SENT","Elkldve");
define("_PREVIOUSMESSAGE","Elz zenet");
define("_NEXTMESSAGE","Kvetkez zenet");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","A kldsrl");
define("_ALLREGCANPOST","Minden regisztrlt tag kldhet szemlyes zeneteket.");
define("_TO","Cmzett");
define("_MESSAGEICON","zenet ikonja");
define("_MESSAGE","zenet");
define("_HTML","HTML");
define("_PMON","On");
define("_PMOFF","Off");
define("_BBCODE","BBCode");
define("_WROTE","rta");
define("_OPTIONS","Belltsok");
define("_HTMLDISSABLE","HTML kikapcsolsa ebben az zenetben");
define("_BBCODEDISSABLE","<a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> kikapcsolsa");
define("_SMILEDISSABLE","<a href=\"bb_smilies.php\" target=\"_blank\"><i>vigyorok</i></a> kikapcsolsa");
define("_CANCELREPLY","Mgsem");
define("_CANCELSEND","Mgsem");
define("_CLEAR","Trls");
define("_SUBMIT","Klds");
define("_USERNOTINDB","Ilyen felhasznl nem ltezik az adatbzisban.");
define("_CHECKNAMEANDTRY","Ellenrizd a nevet, s prbld jra!");
define("_MSGPOSTED","zenet elkldve.");
define("_RETURNTOPMSG","Kattints ide a szemlyes zenetek frisstshez.");
define("_MSGDELETED","zeneteid trlve.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
